
use chrono::Local;
use serenity::all::{CommandInteraction, Context, ResolvedOption, ResolvedValue};
use serenity::builder::{CreateCommand, CreateCommandOption, CreateEmbed, CreateEmbedAuthor, CreateEmbedFooter};
use serenity::model::application::CommandOptionType;

pub fn run(ctx: &Context, command: &CommandInteraction, options: &[ResolvedOption]) -> CreateEmbed {
    let username = command.user.name.as_str();
    let current_time = Local::now().format("%Y-%m-%d @ %H:%M:%S");

    let query = if let Some(ResolvedOption {
        value: ResolvedValue::String(query), ..
    }) = options.first()
    {
        query
    } else {
        return CreateEmbed::new()
        .author(CreateEmbedAuthor::new("Rustendo"))
        .title("Error 400")
        .description("There is no query provied.")
        .footer(CreateEmbedFooter::new(format!(">{} | {}", current_time, username)))
    };

    CreateEmbed::new()
    .author(CreateEmbedAuthor::new("Rustendo"))
    .title(format!("Searching for {}", query))
    .footer(CreateEmbedFooter::new(format!(">{} | {}", current_time, username)))
}


pub fn register() -> CreateCommand {
    CreateCommand::new("play")
    .description("Play music")
    .add_option(
        CreateCommandOption::new(CommandOptionType::String, "query", "Link or search term")
        .required(true)
    )
}